==> pant-react-0.1.40.tgz: package/es/data-list/addons/selectable/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useContext } from 'react';
import { Icon } from '../../../icon';
import { createBEM } from '../../../utils/bem';
import { select } from '../../key-selector';
import { SelectableManager } from './manager';
import './index.scss';
export { SelectableManager };
export var SelectableContext = React.createContext(null);
export function selectable(options) {
    return {
        onInjectRecord: function (render) { return function (props) {
            return _jsx(DataListSelectable, __assign({ dataListRecordProps: props, dataListRecordRender: render }, options), void 0);
        }; },
        onInjectDataList: function (render) { return function (props) {
            return (_jsx(SelectableContext.Provider, __assign({ value: new SelectableManager(props.records, options.value, props.recordKey, options.maxSelection, options.maxSelectionMsg, options.onChange) }, { children: render(props) }), void 0));
        }; },
    };
}
function DataListSelectable(_a) {
    var dataListRecordRender = _a.dataListRecordRender, dataListRecordProps = _a.dataListRecordProps, options = __rest(_a, ["dataListRecordRender", "dataListRecordProps"]);
    return (_jsxs(_Fragment, { children: [_jsx(Selectable, __assign({}, dataListRecordProps, options), void 0),
            dataListRecordRender(__assign({}, dataListRecordProps))] }, void 0));
}
var bem = createBEM('pant-data-list__select');
function Selectable(_a) {
    var record = _a.record, recordIndex = _a.recordIndex, recordKey = _a.recordKey, checkedIcon = _a.checkedIcon, uncheckedIcon = _a.uncheckedIcon;
    var manager = useContext(SelectableContext);
    var key = select(recordKey)(record, recordIndex);
    var toggle = function () { return manager.toggle(key); };
    var icon;
    if (manager.hasKey(key)) {
        icon = (checkedIcon && React.cloneElement(checkedIcon, { onClick: toggle })) || (_jsx(Icon, { name: "passed", onClick: toggle }, void 0));
    }
    else {
        icon = (uncheckedIcon && React.cloneElement(uncheckedIcon, { onClick: toggle })) || (_jsx(Icon, { name: "circle", onClick: toggle }, void 0));
    }
    return _jsx("div", __assign({ className: bem() }, { children: icon }), void 0);
}

==> pant-react-0.2.2.tgz: package/es/data-list/addons/selectable/index.js <==
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useContext } from 'react';
import { Icon } from '../../../icon';
import { createBEM } from '../../../utils/bem';
import { select } from '../../key-selector';
import { SelectableManager } from './manager';
import './index.scss';
export { SelectableManager };
export var SelectableContext = React.createContext(null);
export function selectable(options) {
    return {
        onInjectRecord: function (render) { return function (props) {
            return _jsx(DataListSelectable, __assign({ dataListRecordProps: props, dataListRecordRender: render }, options), void 0);
        }; },
        onInjectDataList: function (render) { return function (props) {
            return (_jsx(SelectableContext.Provider, __assign({ value: new SelectableManager(props.records, options.value, props.recordKey, options.maxSelection, options.maxSelectionMsg, options.onChange) }, { children: render(props) }), void 0));
        }; },
    };
}
function DataListSelectable(_a) {
    var dataListRecordRender = _a.dataListRecordRender, dataListRecordProps = _a.dataListRecordProps, options = __rest(_a, ["dataListRecordRender", "dataListRecordProps"]);
    return (_jsxs(_Fragment, { children: [_jsx(Selectable, __assign({}, dataListRecordProps, options), void 0),
            dataListRecordRender(__assign({}, dataListRecordProps))] }, void 0));
}
var bem = createBEM('pant-data-list__select');
function Selectable(_a) {
    var record = _a.record, recordIndex = _a.recordIndex, recordKey = _a.recordKey, maxSelection = _a.maxSelection, checkedIcon = _a.checkedIcon, uncheckedIcon = _a.uncheckedIcon, singleCheckedIcon = _a.singleCheckedIcon, singleUncheckedIcon = _a.singleUncheckedIcon;
    var manager = useContext(SelectableContext);
    var key = select(recordKey)(record, recordIndex);
    var toggle = function () { return manager.toggle(key); };
    var icon;
    if (manager.hasKey(key)) {
        icon =
            maxSelection === 1 && singleCheckedIcon
                ? React.cloneElement(singleCheckedIcon, { onClick: toggle })
                : (checkedIcon && React.cloneElement(checkedIcon, { onClick: toggle })) || (_jsx(Icon, { name: "passed", onClick: toggle }, void 0));
    }
    else {
        icon =
            maxSelection === 1 && singleUncheckedIcon
                ? React.cloneElement(singleUncheckedIcon, { onClick: toggle })
                : (uncheckedIcon && React.cloneElement(uncheckedIcon, { onClick: toggle })) || (_jsx(Icon, { name: "circle", onClick: toggle }, void 0));
    }
    return _jsx("div", __assign({ className: bem() }, { children: icon }), void 0);
}
